<?php

	App::uses('CakeEventListener', 'Event');

	class DeliveryCalculatorListener implements CakeEventListener {

		public $default_vat_rate_id = 1;

		public function implementedEvents() {
			return array(
				'Model.Order.updateOrderTotal' => 'calculateDeliveryCost',
			);
		}

		public function calculateDeliveryCost(CakeEvent $event) {
			
			$orderTotal = $event->data['Order']['Order']['subtotal'] + $event->data['Order']['Order']['vat'];
			
			//Check if site settings allows free delivery over a given threshold 
			$freeShippingThreshold = Configure::read('SiteSetting.free_delivery_threshold');

			//IF site setting has not been set there is nothing for us to do
			if($freeShippingThreshold !== null) {

				//Check if free shipping applies
				if($freeShippingThreshold !== null  && $freeShippingThreshold <= $orderTotal) {

					$deliveryCost = 0;

				} elseif(Configure::read('SiteSetting.fixed_delivery_cost') !== null) {

					$deliveryCost = Configure::read('SiteSetting.fixed_delivery_cost');
					
				}

				
				//Add VAT
				$vat = 0;
				if($this->default_vat_rate_id !== null) {

					$VatRate = ClassRegistry::init('EvCheckout.VatRate');

					$vatRate = $VatRate->findById($this->default_vat_rate_id);

					if($vatRate) {

						$vat = ($vatRate[$VatRate->alias]['rate']/100) * $deliveryCost;

					}

				}

				//Update total 
				$event->data['Order']['Order']['delivery_subtotal'] = $deliveryCost;
				$event->data['Order']['Order']['delivery_vat'] = $vat;
				$event->data['Order']['Order']['delivery_total'] = $deliveryCost + $vat;

				$event->data['Order']['Order']['total'] += $deliveryCost + $vat;
				$event->data['Order']['Order']['vat'] += $vat;


			}

		}

	}
